##  Adding Diagrams to Your Favorites
You can add a diagram to your favorites to access it quickly. To add a diagram to your favorites, choose the star icon on the diagram card or next to the diagram’s name. When a diagram is added to your favorites, the star turns blue.
Access your favorite diagrams in the Favorites section under Diagrams > Personal.
**Note**
You can have an unlimited number of favorites. However, adding too many diagrams to your favorites can reduce the effectiveness of the "Add to favorites" feature.
To remove a diagram from your favorites, choose the blue star icon.
